@@ -1,19 +1,10 @@
 // Copyright (C) 2021 Mathieu Duponchelle <mathieu@centricular.com>
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// This Source Code Form is subject to the terms of the Mozilla Public License, v2.0.
+// If a copy of the MPL was not distributed with this file, You can obtain one at
+// <https://mozilla.org/MPL/2.0/>.
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the
-// Free Software Foundation, Inc., 51 Franklin Street, Suite 500,
-// Boston, MA 02110-1335, USA.
+// SPDX-License-Identifier: MPL-2.0
 
 use gst::glib;
 use gst::gst_error;
@@ -44,16 +35,11 @@ struct Command {
     operation: Operation,
 }
 
+#[derive(Default)]
 struct State {
     commands: Vec<Command>,
 }
 
-impl Default for State {
-    fn default() -> Self {
-        Self { commands: vec![] }
-    }
-}
-
 pub struct RegEx {
     srcpad: gst::Pad,
     sinkpad: gst::Pad,
@@ -156,17 +142,17 @@ impl ObjectSubclass for RegEx {
 impl ObjectImpl for RegEx {
     fn properties() -> &'static [glib::ParamSpec] {
         static PROPERTIES: Lazy<Vec<glib::ParamSpec>> = Lazy::new(|| {
-            vec![glib::ParamSpec::new_array(
+            vec![gst::ParamSpecArray::new(
                 "commands",
                 "Commands",
                 "A set of commands to apply on input text",
-                &glib::ParamSpec::new_boxed(
+                Some(&glib::ParamSpecBoxed::new(
                     "command",
                     "Command",
                     "A command to apply on input text",
                     gst::Structure::static_type(),
                     glib::ParamFlags::READWRITE,
-                ),
+                )),
                 glib::ParamFlags::READWRITE | gst::PARAM_FLAG_MUTABLE_PLAYING,
             )]
         });
@@ -192,7 +178,7 @@ impl ObjectImpl for RegEx {
             "commands" => {
                 let mut state = self.state.lock().unwrap();
                 state.commands = vec![];
-                let commands: gst::Array = value.get().expect("type checked upstream");
+                let commands = value.get::<gst::ArrayRef>().expect("type checked upstream");
                 for command in commands.as_slice() {
                     let s = match command
                         .get::<Option<gst::Structure>>()
@@ -258,22 +244,24 @@ impl ObjectImpl for RegEx {
                     match command.operation {
                         Operation::ReplaceAll(ref replacement) => {
                             commands.push(
-                                gst::Structure::new(
-                                    "replace-all",
-                                    &[("pattern", &command.pattern), ("replacement", &replacement)],
-                                )
-                                .to_send_value(),
+                                gst::Structure::builder("replace-all")
+                                    .field("pattern", &command.pattern)
+                                    .field("replacement", replacement)
+                                    .build()
+                                    .to_send_value(),
                             );
                         }
                     }
                 }
-                gst::Array::from_owned(commands).to_value()
+                gst::Array::from(commands).to_value()
             }
             _ => unimplemented!(),
         }
     }
 }
 
+impl GstObjectImpl for RegEx {}
+
 impl ElementImpl for RegEx {
     fn metadata() -> Option<&'static gst::subclass::ElementMetadata> {
         static ELEMENT_METADATA: Lazy<gst::subclass::ElementMetadata> = Lazy::new(|| {
@@ -291,7 +279,7 @@ impl ElementImpl for RegEx {
     fn pad_templates() -> &'static [gst::PadTemplate] {
         static PAD_TEMPLATES: Lazy<Vec<gst::PadTemplate>> = Lazy::new(|| {
             let caps = gst::Caps::builder("text/x-raw")
-                .field("format", &"utf8")
+                .field("format", "utf8")
                 .build();
             let src_pad_template = gst::PadTemplate::new(
                 "src",
